@@ -1,5 +1,5 @@
 #' Data Validation Infrastructure
-#' 
+#'
 #' 
 #' Data often suffer from errors and missing values. A necessary step before data
 #' analysis is verifying and validating your data. Package \code{validate} is a
@@ -30,7 +30,7 @@
 #' Please use \code{citation("validate")} to get a citation for (scientific)
 #' publications.
 #'
-#' @docType package
+#' @aliases validate-package 
 #' @name validate
 #' @useDynLib validate, .registration=TRUE
 #' @aliases package-validate validate
@@ -40,4 +40,6 @@
 #' @import settings
 #' @import yaml
 #' @import grid
-NULL
+"_PACKAGE"
+
+
